@@ -112,12 +112,14 @@ List z_mFLSSS(int maxCore, int len, NumericMatrix vr,
               bool useBiSearch = 0)
 {
   int vlen = vr.nrow();
-  // double endTime = (double)std::clock() + duration * CLOCKS_PER_SEC;
   std::chrono::time_point<std::chrono::steady_clock> endTime =
     std::chrono::steady_clock::now() + std::chrono::seconds(std::size_t(duration));
   List result;
-  INT *mask = (INT*)&maskV[0];
   bool mk = maskV.size() > 0;
+  INT *mask = nullptr;
+  if (mk) mask = (INT*)&maskV[0];
+  
+  
   if(std::max(vlen, d) < 127)
   {
          if(mk == 0 and useBiSearch == 0) result = mFLSSScpp<double, signed char, 0, 0> (
